@@ -18,8 +18,6 @@
 
 #include <stdarg.h>
 
-#include <glib/gi18n.h>
-
 #include "gom-filter.h"
 #include "gom-resource.h"
 
@@ -60,7 +58,9 @@ static const gchar *gOperators[] = {
    "<",
    "<=",
    "LIKE",
-   "GLOB"
+   "GLOB",
+   "IS NULL",
+   "IS NOT NULL"
 };
 
 /**
@@ -73,14 +73,35 @@ static const gchar *gOperators[] = {
  * Returns: (transfer full): A new #GomFilter.
  */
 GomFilter *
-gom_filter_new_sql (const gchar *sql,
-                    GArray      *values)
+gom_filter_new_sql (const gchar  *sql,
+                    const GArray *values)
 {
-   GomFilter *filter = g_object_new(GOM_TYPE_FILTER,
-                                    "mode", GOM_FILTER_SQL,
-                                    "sql", sql,
-                                    NULL);
-   filter->priv->values = g_array_ref(values);
+   GomFilter *filter;
+
+   g_return_val_if_fail (sql != NULL, NULL);
+
+   filter = g_object_new (GOM_TYPE_FILTER,
+                          "mode", GOM_FILTER_SQL,
+                          "sql", sql,
+                          NULL);
+
+   if (values != NULL) {
+      guint i;
+
+      filter->priv->values = g_array_sized_new (FALSE, FALSE, sizeof(GValue), values->len);
+      g_array_set_clear_func (filter->priv->values, (GDestroyNotify)g_value_unset);
+
+      for (i = 0; i < values->len; i++) {
+         GValue copy = { 0 };
+         const GValue *src;
+
+         src = &g_array_index (values, GValue, i);
+         g_value_init (&copy, G_VALUE_TYPE (src));
+         g_value_copy (src, &copy);
+         g_array_append_val (filter->priv->values, copy);
+      }
+   }
+
    return filter;
 }
 
@@ -95,8 +116,10 @@ gom_filter_new_for_param (GType          resource_type,
    GomFilter *filter;
 
    g_return_val_if_fail(g_type_is_a(resource_type, GOM_TYPE_RESOURCE), NULL);
-   g_return_val_if_fail(value != NULL, NULL);
-   g_return_val_if_fail(G_VALUE_TYPE(value), NULL);
+   if (mode != GOM_FILTER_IS_NULL && mode != GOM_FILTER_IS_NOT_NULL) {
+     g_return_val_if_fail(value != NULL, NULL);
+     g_return_val_if_fail(G_VALUE_TYPE(value), NULL);
+   }
 
    klass = g_type_class_ref(resource_type);
    pspec = g_object_class_find_property(klass, property_name);
@@ -113,8 +136,12 @@ gom_filter_new_for_param (GType          resource_type,
                          NULL);
    filter->priv->pspec = g_param_spec_ref(pspec);
    filter->priv->type = resource_type;
-   g_value_init(&filter->priv->value, G_VALUE_TYPE(value));
-   g_value_copy(value, &filter->priv->value);
+
+   if (value)
+     {
+       g_value_init(&filter->priv->value, G_VALUE_TYPE(value));
+       g_value_copy(value, &filter->priv->value);
+     }
 
    return filter;
 }
@@ -232,6 +259,20 @@ gom_filter_new_lte (GType         resource_type,
    return gom_filter_new_for_param(resource_type, property_name, GOM_FILTER_LTE, value);
 }
 
+GomFilter   *
+gom_filter_new_is_null (GType          resource_type,
+                        const gchar   *property_name)
+{
+   return gom_filter_new_for_param(resource_type, property_name, GOM_FILTER_IS_NULL, NULL);
+}
+
+GomFilter   *
+gom_filter_new_is_not_null (GType          resource_type,
+                            const gchar   *property_name)
+{
+   return gom_filter_new_for_param(resource_type, property_name, GOM_FILTER_IS_NOT_NULL, NULL);
+}
+
 static GomFilterMode
 gom_filter_get_mode (GomFilter *filter)
 {
@@ -420,6 +461,15 @@ gom_filter_get_sql (GomFilter  *filter,
                             gOperators[priv->mode]);
       g_free(table);
       return ret;
+   case GOM_FILTER_IS_NULL:
+   case GOM_FILTER_IS_NOT_NULL:
+      table = get_table(priv->pspec, priv->type, table_map);
+      ret = g_strdup_printf("'%s'.'%s' %s",
+                            table,
+                            priv->pspec->name,
+                            gOperators[priv->mode]);
+      g_free(table);
+      return ret;
    case GOM_FILTER_AND:
    case GOM_FILTER_OR:
       len = g_queue_get_length(priv->subfilters);
@@ -521,6 +571,11 @@ gom_filter_get_values (GomFilter *filter)
       g_array_append_val(va, v);
       return va;
    }
+   case GOM_FILTER_IS_NULL:
+   case GOM_FILTER_IS_NOT_NULL:
+      va = g_array_new(FALSE, FALSE, sizeof(GValue));
+      g_array_set_clear_func(va, (GDestroyNotify) g_value_unset);
+      return va;
    case GOM_FILTER_AND:
    case GOM_FILTER_OR:
       len = g_queue_get_length(priv->subfilters);
@@ -563,6 +618,8 @@ gom_filter_finalize (GObject *object)
       g_value_unset(&priv->value);
    }
 
+   g_clear_pointer (&priv->values, g_array_unref);
+
    if (priv->subfilters != NULL)
       g_queue_free_full(priv->subfilters, g_object_unref);
 
@@ -643,8 +700,8 @@ gom_filter_class_init (GomFilterClass *klass)
 
    gParamSpecs[PROP_MODE] =
       g_param_spec_enum("mode",
-                        _("Mode"),
-                        _("The mode of the filter."),
+                        "Mode",
+                        "The mode of the filter.",
                         GOM_TYPE_FILTER_MODE,
                         GOM_FILTER_SQL,
                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
@@ -653,8 +710,8 @@ gom_filter_class_init (GomFilterClass *klass)
 
    gParamSpecs[PROP_SQL] =
       g_param_spec_string("sql",
-                          _("SQL"),
-                          _("The SQL for the filter."),
+                          "SQL",
+                          "The SQL for the filter.",
                           NULL,
                           G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY);
    g_object_class_install_property(object_class, PROP_SQL,
@@ -694,6 +751,8 @@ gom_filter_mode_get_type (void)
       { GOM_FILTER_LTE, "GOM_FILTER_LTE", "LTE" },
       { GOM_FILTER_LIKE, "GOM_FILTER_LIKE", "LIKE" },
       { GOM_FILTER_GLOB, "GOM_FILTER_GLOB", "GLOB" },
+      { GOM_FILTER_IS_NULL, "GOM_FILTER_IS_NULL", "IS_NULL" },
+      { GOM_FILTER_IS_NOT_NULL, "GOM_FILTER_IS_NOT_NULL", "IS_NOT_NULL" },
       { 0 }
    };
 
