@@ -16,8 +16,8 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <glib/gi18n.h>
 #include <sqlite3.h>
+#include <string.h>
 
 #include "gom-command.h"
 #include "gom-command-builder.h"
@@ -26,6 +26,7 @@
 #include "gom-repository.h"
 #include "gom-resource.h"
 #include "gom-resource-priv.h"
+#include "reserved-keywords.h"
 
 G_DEFINE_ABSTRACT_TYPE(GomResource, gom_resource, G_TYPE_OBJECT)
 
@@ -43,7 +44,6 @@ enum
 };
 
 static GParamSpec *gParamSpecs[LAST_PROP];
-static GHashTable *gPropMaps;
 
 void
 gom_resource_class_set_primary_key (GomResourceClass *resource_class,
@@ -201,6 +201,19 @@ gom_resource_class_set_reference (GomResourceClass     *resource_class,
                                g_strdup(ref_property_name), g_free);
 }
 
+static gboolean
+is_valid_table_name (const gchar *table)
+{
+   guint i;
+
+   for (i = 0; i < G_N_ELEMENTS (reserved_keywords); i++) {
+      if (g_ascii_strcasecmp (reserved_keywords[i], table) == 0)
+         return FALSE;
+   }
+
+   return TRUE;
+}
+
 void
 gom_resource_class_set_table (GomResourceClass *resource_class,
                               const gchar      *table)
@@ -208,6 +221,7 @@ gom_resource_class_set_table (GomResourceClass *resource_class,
    g_return_if_fail(GOM_IS_RESOURCE_CLASS(resource_class));
    g_return_if_fail(table != NULL);
    g_return_if_fail(strlen(table) <= sizeof(resource_class->table));
+   g_return_if_fail(is_valid_table_name(table));
 
    g_snprintf(resource_class->table,
               sizeof(resource_class->table),
@@ -743,7 +757,7 @@ gom_resource_save_sync (GomResource  *resource,
 
    if (!priv->repository) {
       g_set_error(error, GOM_ERROR, GOM_ERROR_COMMAND_NO_REPOSITORY,
-                  _("Cannot save resource, no repository set"));
+                  "Cannot save resource, no repository set");
       return FALSE;
    }
 
@@ -873,7 +887,7 @@ gom_resource_fetch_m2m_cb (GomAdapter *adapter,
    if (!gom_cursor_next(cursor)) {
       g_simple_async_result_set_error(simple, GOM_ERROR,
                                       GOM_ERROR_RESOURCE_CURSOR,
-                                      _("No result was returned from the cursor."));
+                                      "No result was returned from the cursor.");
       goto out;
    }
 
@@ -1034,6 +1048,36 @@ gom_resource_set_property (GObject      *object,
    }
 }
 
+static void
+pkey_changed_cb (GObject    *gobject,
+                 GParamSpec *pspec,
+                 gpointer    user_data)
+{
+  GomResource *resource = (GomResource *) gobject;
+
+  /* Did the developer reset the primary key? */
+  if (!has_primary_key(GOM_RESOURCE(resource))) {
+     resource->priv->is_from_table = FALSE;
+  }
+}
+
+static void
+gom_resource_constructed (GObject *object)
+{
+  char *pkey_signal;
+  GomResourceClass *klass;
+
+  /* Monitor the primary key */
+  klass = GOM_RESOURCE_CLASS (G_OBJECT_GET_CLASS(object));
+  g_assert (klass->primary_key[0] != '\0');
+  pkey_signal = g_strdup_printf("notify::%s", klass->primary_key);
+  g_signal_connect (G_OBJECT (object), pkey_signal,
+                    G_CALLBACK (pkey_changed_cb), NULL);
+  g_free(pkey_signal);
+
+  G_OBJECT_CLASS (gom_resource_parent_class)->constructed (object);
+}
+
 /**
  * gom_resource_class_init:
  * @klass: (in): A #GomResourceClass.
@@ -1049,34 +1093,19 @@ gom_resource_class_init (GomResourceClass *klass)
    object_class->finalize = gom_resource_finalize;
    object_class->get_property = gom_resource_get_property;
    object_class->set_property = gom_resource_set_property;
+   object_class->constructed = gom_resource_constructed;
    g_type_class_add_private(object_class, sizeof(GomResourcePrivate));
 
-   gPropMaps = g_hash_table_new_full(g_direct_hash, g_direct_equal, NULL,
-                                     (GDestroyNotify)g_hash_table_destroy);
-
    gParamSpecs[PROP_REPOSITORY] =
       g_param_spec_object("repository",
-                          _("Repository"),
-                          _("The resources repository."),
+                          "Repository",
+                          "The resources repository.",
                           GOM_TYPE_REPOSITORY,
                           G_PARAM_READWRITE);
    g_object_class_install_property(object_class, PROP_REPOSITORY,
                                    gParamSpecs[PROP_REPOSITORY]);
 }
 
-static void
-pkey_changed_cb (GObject    *gobject,
-                 GParamSpec *pspec,
-                 gpointer    user_data)
-{
-  GomResource *resource = (GomResource *) gobject;
-
-  /* Did the developer reset the primary key? */
-  if (!has_primary_key(GOM_RESOURCE(resource))) {
-     resource->priv->is_from_table = FALSE;
-  }
-}
-
 /**
  * gom_resource_init:
  * @resource: (in): A #GomResource.
@@ -1086,20 +1115,10 @@ pkey_changed_cb (GObject    *gobject,
 static void
 gom_resource_init (GomResource *resource)
 {
-   char *pkey_signal;
-   GomResourceClass *klass;
-
    resource->priv =
       G_TYPE_INSTANCE_GET_PRIVATE(resource,
                                   GOM_TYPE_RESOURCE,
                                   GomResourcePrivate);
-
-   /* Monitor the primary key */
-   klass = GOM_RESOURCE_CLASS (G_OBJECT_GET_CLASS(resource));
-   pkey_signal = g_strdup_printf("notify::%s", klass->primary_key);
-   g_signal_connect (G_OBJECT (resource), pkey_signal,
-                     G_CALLBACK (pkey_changed_cb), NULL);
-   g_free(pkey_signal);
 }
 
 gboolean
